unit OptionsFrame;
// (c)2006 by Paul TOTH <tothpaul@free.fr>
// http://tothpaul.free.fr

{
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, MMSystem, ExButtons;

type
  TOptions = class(TFrame)
    RememberPassword: TCheckBox;
    DoNotDisturb: TCheckBox;
    WaveOutList: TComboBox;
    WaveOutTest: TLabel;
    Label13: TLabel;
    WaveInList: TComboBox;
    Test: TButton;
    LogFile: TCheckBox;
    procedure WaveOutListChange(Sender: TObject);
    procedure WaveInListChange(Sender: TObject);
    procedure DoNotDisturbClick(Sender: TObject);
    procedure TestClick(Sender: TObject);
    procedure LogFileClick(Sender: TObject);
  private
    { Private declarations }
    fLogFile:TextFile;
  public
    { Public declarations }
    procedure Log(const s:string);
    procedure CheckDevices;
    procedure SetWaveIn(const Name:string);
    procedure SetWaveOut(const Name:string);
    function WaveInName:string;
    function WaveOutName:string;
  end;

implementation

uses main, SoudTest;

{$R *.dfm}

procedure TOptions.WaveOutListChange(Sender: TObject);
begin
 MainForm.PCMA.DevOut:=WaveOutList.ItemIndex;
end;

procedure TOptions.WaveInListChange(Sender: TObject);
begin
 MainForm.PCMA.DevIn:=WaveInList.ItemIndex;
end;

procedure TOptions.DoNotDisturbClick(Sender: TObject);
var
 b:boolean;
begin
 b:=TCheckBox(Sender).Checked;
 if TCheckBox(Sender).Tag=1 then begin
  DoNotDisturb.Checked:=b;
 end else begin
  MainForm.DoNotDisturb2.Checked:=b;
 end;
 MainForm.Ini.WriteBool(MainForm.UserID.Text,'DoNotDisturb',b);
 MainForm.SIP.Accept:=(b=False);
end;

procedure TOptions.CheckDevices;
var
 Handle:HKEY;
 RegType:integer;
 DataSize:integer;
 smPlayback:string;
 smRecord  :string;
 i,count:integer;
 info:TWaveOutCaps;
 list:TStringList;
 ok:boolean;
begin
// priphriques par dfaut
 if (RegOpenKeyEx(HKEY_CURRENT_USER,'Software\Microsoft\Multimedia\Sound Mapper',0,KEY_ALL_ACCESS,Handle)=ERROR_SUCCESS) then begin
  if RegQueryValueEx(Handle,'Playback',nil,@RegType,nil,@DataSize)=ERROR_SUCCESS then begin
   SetLength(smPlayback,Datasize);
   RegQueryValueEx(Handle,'Playback',nil,@RegType,PByte(@smPlayback[1]),@DataSize);
   SetLength(smPlayback,Datasize-1);
  end;
  if RegQueryValueEx(Handle,'Record',nil,@RegType,nil,@DataSize)=ERROR_SUCCESS then begin
   SetLength(smRecord,Datasize);
   RegQueryValueEx(Handle,'Record',nil,@RegType,PByte(@smRecord[1]),@DataSize);
   SetLength(smRecord,Datasize-1);
  end;
  RegCloseKey(Handle);
 end;
//
 ok:=True;
 list:=TStringList.Create;
 try
 // waveOut devices
  count:=waveOutGetNumDevs();
  for i:=0 to count-1 do begin
   if waveOutGetDevCaps(i, @info, SizeOf(Info))=0 then begin
    list.Add(info.szPname);
   end;
  end;

  if List.Count=0 then begin
   ok:=False;
   WaveOutList.Items.Clear;
   MainForm.PCMA.DevOut:=-1;
  end else begin
   i:=WaveOutList.ItemIndex;
   WaveOutList.Items.Assign(List);
   if i<0 then i:=List.IndexOf(smPlayback);
   if (i<0)or(i>=List.Count) then i:=0;
   WaveOutlist.ItemIndex:=i;
   MainForm.PCMA.DevOut:=i;
   List.Clear;
  end;

 // waveIn devices
  count:=waveInGetNumDevs();
  for i:=0 to count-1 do begin
   if waveInGetDevCaps(i, @info, SizeOf(Info))=0 then begin
    List.Add(info.szPname);
   end;
  end;

  if List.Count=0 then begin
   ok:=False;
   WaveInList.Items.Clear;
   MainForm.PCMA.DevIn:=-1;
  end else begin
   i:=WaveInList.ItemIndex;
   if i<0 then i:=List.IndexOf(smRecord);
   WaveInList.Items.Assign(List);
   if (i<0)or(i>=List.Count) then i:=0;
   WaveInlist.ItemIndex:=i;
   MainForm.PCMA.DevIn:=i;
   List.Clear;
  end;

 finally
  List.Free;
 end;

 MainForm.Connect.Enabled:=ok;
end;


procedure TOptions.SetWaveIn(const Name:string);
var
 i:integer;
begin
 if Name='' then exit;
 i:=WaveInList.Items.IndexOf(Name);
 if i<0 then exit;
 WaveInList.ItemIndex:=i;
 MainForm.PCMA.DevIn:=i;
end;

procedure TOptions.SetWaveOut(const Name:string);
var
 i:integer;
begin
 if Name='' then exit;
 i:=WaveOutList.Items.IndexOf(Name);
 if i<0 then exit;
 WaveOutList.ItemIndex:=i;
 MainForm.PCMA.DevOut:=i;
end;

function TOptions.WaveInName:string;
begin
 Result:=WaveInList.Items[WaveInList.ItemIndex]
end;

function TOptions.WaveOutName:string;
begin
 Result:=WaveOutList.Items[WaveOutList.ItemIndex]
end;

procedure TOptions.TestClick(Sender: TObject);
begin
 with TSoundTest.Create(Self) do begin
  try
   ShowModal;
  finally
   Free;
  end;
 end;
end;

procedure TOptions.LogFileClick(Sender: TObject);
begin
 if LogFile.Checked=False then
  CloseFile(fLogFile)
 else begin
  try
   AssignFile(fLogFile,'SIPInside.log');
   Rewrite(fLogFile);
  except
   on e:Exception do begin
    CloseFile(fLogFile);
    LogFile.Checked:=False;
    ShowMessage(e.Message);
   end;
  end;
 end;
end;

procedure TOptions.Log(const s:string);
begin
 if LogFile.Checked then
  WriteLn(fLogFile,s);
end;

end.

